@@ -568,6 +568,12 @@ impl EnvVars {
     #[attr_added_in("0.9.15")]
     pub const UV_INTERNAL__TEST_LFS_DISABLED: &'static str = "UV_INTERNAL__TEST_LFS_DISABLED";
 
+    /// Marker variable to track whether `PYTHONHOME` was set by uv.
+    /// Used by the Windows trampoline to distinguish uv-set values from user-set values.
+    #[attr_hidden]
+    #[attr_added_in("0.9.29")]
+    pub const UV_INTERNAL__PYTHONHOME: &'static str = "UV_INTERNAL__PYTHONHOME";
+
     /// Path to system-level configuration directory on Unix systems.
     #[attr_added_in("0.4.26")]
     pub const XDG_CONFIG_DIRS: &'static str = "XDG_CONFIG_DIRS";
